pub struct FramedWriter<W: AsyncWrite + Unpin> { /* private fields */ }Expand description
Async writer that frames Crous data into blocks over a Tokio stream.
Implementations
Sourceimpl<W: AsyncWrite + Unpin> FramedWriter<W>
impl<W: AsyncWrite + Unpin> FramedWriter<W>
pub fn new(writer: W) -> Self
pub fn with_flags(writer: W, flags: u8) -> Self
Sourcepub async fn write_block(&mut self, block: &[u8]) -> Result<()>
pub async fn write_block(&mut self, block: &[u8]) -> Result<()>
Write a pre-built block.
Sourcepub async fn write_data(&mut self, payload: &[u8]) -> Result<()>
pub async fn write_data(&mut self, payload: &[u8]) -> Result<()>
Write a raw data payload as a framed block.
Sourcepub fn into_inner(self) -> W
pub fn into_inner(self) -> W
Consume the writer and return the inner stream.